@@ -16,10 +16,12 @@
 #include <ktexteditor/message.h>
 #include <ktexteditor/movingcursor.h>
 
+#include <KLineEdit>
 #include <QScrollBar>
 #include <QSignalSpy>
 #include <QStandardPaths>
 #include <QTemporaryFile>
+#include <QTextLayout>
 #include <QtTestWidgets>
 
 #define testNewRow() (QTest::newRow(QStringLiteral("line %1").arg(__LINE__).toLatin1().data()))
@@ -487,8 +489,7 @@ void KateViewTest::testDragAndDrop()
     view->setSelection(Range(1, 0, 2, 0));
     QCOMPARE(view->selectionRange(), Range(1, 0, 2, 0));
 
-    (void)QTest::qWaitForWindowExposed(view);
-    QTest::qWait(100); // For whatever reason needed
+    QVERIFY(QTest::qWaitForWindowExposed(view));
 
     const QPoint startDragPos = internalView->mapFrom(view, view->cursorToCoordinate(KTextEditor::Cursor(1, 2)));
     const QPoint endDragPos = internalView->mapFrom(view, view->cursorToCoordinate(KTextEditor::Cursor(3, 0)));
@@ -789,4 +790,55 @@ void KateViewTest::testCrashOnPasteInOverwriteMode()
     QCOMPARE(doc.text(), QStringLiteral("test1\ntest2\ntest1\ntest2\ntest3\n"));
 }
 
+void KateViewTest::testCommandBarSearchReplace()
+{
+    KTextEditor::DocumentPrivate doc(false, false);
+    const QString testText(QStringLiteral("hello\nhello\nabc\nhello"));
+    doc.setText(testText);
+
+    KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
+    view->switchToCmdLine();
+    const auto childs = view->findChildren<QWidget *>();
+    KLineEdit *lineEdit = nullptr;
+    for (auto c : childs) {
+        if (strcmp("KateCmdLineEdit", c->metaObject()->className()) == 0) {
+            lineEdit = qobject_cast<KLineEdit *>(c);
+            break;
+        }
+    }
+    QVERIFY(lineEdit);
+    lineEdit->returnKeyPressed(QStringLiteral("%s/hell/bell"));
+    QCOMPARE(doc.text(), QStringLiteral("bello\nbello\nabc\nbello"));
+}
+
+void KateViewTest::testSelectedTextFormats()
+{
+    KTextEditor::DocumentPrivate doc(false, false);
+    const QString testText(QStringLiteral("- []KOrganizer: add more new stuff to the Whatsnew dialog\n"));
+    QVERIFY(doc.setHighlightingMode(QStringLiteral("Markdown")));
+    doc.setText(testText);
+
+    KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
+    view->setCursorPosition({0, 6});
+    view->setSelection({0, 3, 0, 6});
+    QCOMPARE(view->selectionRange(), KTextEditor::Range(0, 3, 0, 6));
+
+    const QTextLayout *layout = view->textLayout({0, 0});
+    QVERIFY(layout);
+    const auto formats = layout->formats();
+    QCOMPARE(formats.size(), 4);
+
+    auto verifyFormat = [](const QTextLayout::FormatRange &f, int start, int length, bool bg, bool fg) {
+        QCOMPARE(f.start, start);
+        QCOMPARE(f.length, length);
+        QCOMPARE(f.format.hasProperty(QTextFormat::BackgroundBrush), bg);
+        QCOMPARE(f.format.hasProperty(QTextFormat::ForegroundBrush), fg);
+    };
+
+    verifyFormat(formats[0], 0, 2, /*hasBg=*/false, /*hasFg=*/true);
+    verifyFormat(formats[1], 2, 1, /*hasBg=*/false, /*hasFg=*/true);
+    verifyFormat(formats[2], 3, 3, /*hasBg=*/false, /*hasFg=*/true);
+    verifyFormat(formats[3], 6, 51, /*hasBg=*/false, /*hasFg=*/true);
+}
+
 // kate: indent-mode cstyle; indent-width 4; replace-tabs on;
