@@ -776,21 +776,13 @@ KateViewDefaultsConfig::KateViewDefaultsConfig(QWidget *parent)
         ui->cmbDynamicWordWrapIndicator->setEnabled(cbx->isChecked());
         ui->sbDynamicWordWrapDepth->setEnabled(cbx->isChecked());
     };
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-    connect(textareaUi->cbxWordWrap, &QCheckBox::stateChanged, this, a);
-#else
     connect(textareaUi->cbxWordWrap, &QCheckBox::checkStateChanged, this, a);
-#endif
     a();
     auto b = [cbx = textareaUi->cbxIndentWrappedLines, sb = textareaUi->sbDynamicWordWrapDepth]() {
         sb->setEnabled(cbx->isChecked());
     };
     b();
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-    connect(textareaUi->cbxIndentWrappedLines, &QCheckBox::stateChanged, this, b);
-#else
     connect(textareaUi->cbxIndentWrappedLines, &QCheckBox::checkStateChanged, this, b);
-#endif
     observeChanges(textareaUi->cbxIndentWrappedLines);
     observeChanges(textareaUi->sbDynamicWordWrapDepth);
     observeChanges(textareaUi->sliSetMarkerSize);
@@ -1010,6 +1002,7 @@ KateSaveConfigTab::KateSaveConfigTab(QWidget *parent)
     observeChanges(ui->spbAutoSaveInterval);
 
     observeChanges(uiadv->chkAutoReloadVersionControl);
+    observeChanges(uiadv->chkAutoReloadOnExternalChanges);
 
     observeChanges(uiadv->chkBackupLocalFiles);
     observeChanges(uiadv->chkBackupRemoteFiles);
@@ -1126,6 +1119,7 @@ void KateSaveConfigTab::apply()
     KateDocumentConfig::global()->setValue(KateDocumentConfig::AutoSaveInteral, ui->spbAutoSaveInterval->value());
 
     KateDocumentConfig::global()->setValue(KateDocumentConfig::AutoReloadIfStateIsInVersionControl, uiadv->chkAutoReloadVersionControl->isChecked());
+    KateDocumentConfig::global()->setValue(KateDocumentConfig::AutoReloadOnExternalChanges, uiadv->chkAutoReloadOnExternalChanges->isChecked());
     KateDocumentConfig::global()->setValue(KateDocumentConfig::UseEditorConfig, uiadv->chkEditorConfig->isChecked());
 
     KateDocumentConfig::global()->configEnd();
@@ -1196,6 +1190,7 @@ void KateSaveConfigTab::reload()
     ui->spbAutoSaveInterval->setValue(KateDocumentConfig::global()->autoSaveInterval());
 
     uiadv->chkAutoReloadVersionControl->setChecked(KateDocumentConfig::global()->value(KateDocumentConfig::AutoReloadIfStateIsInVersionControl).toBool());
+    uiadv->chkAutoReloadOnExternalChanges->setChecked(KateDocumentConfig::global()->value(KateDocumentConfig::AutoReloadOnExternalChanges).toBool());
     uiadv->chkEditorConfig->setChecked(KateDocumentConfig::global()->value(KateDocumentConfig::UseEditorConfig).toBool());
 }
 
