@@ -142,11 +142,14 @@ void KateRenderer::setShowSelections(bool showSelections)
     m_showSelections = showSelections;
 }
 
-void KateRenderer::increaseFontSizes(qreal step) const
+void KateRenderer::addToFontSize(qreal step) const
 {
+    // ensure we don't run into corner cases in Qt, bug 500766
     QFont f(config()->baseFont());
-    f.setPointSizeF(f.pointSizeF() + step);
-    config()->setFont(f);
+    if (auto newS = f.pointSizeF() + step; newS >= 4 && newS <= 2048) {
+        f.setPointSizeF(newS);
+        config()->setFont(f);
+    }
 }
 
 void KateRenderer::resetFontSizes() const
@@ -155,15 +158,6 @@ void KateRenderer::resetFontSizes() const
     config()->setFont(f);
 }
 
-void KateRenderer::decreaseFontSizes(qreal step) const
-{
-    QFont f(config()->baseFont());
-    if ((f.pointSizeF() - step) > 0) {
-        f.setPointSizeF(f.pointSizeF() - step);
-    }
-    config()->setFont(f);
-}
-
 bool KateRenderer::isPrinterFriendly() const
 {
     return m_printerFriendly;
@@ -425,7 +419,7 @@ static bool rangeLessThanForRenderer(const Kate::TextRange *a, const Kate::TextR
     return a->start().toCursor() < b->start().toCursor();
 }
 
-QList<QTextLayout::FormatRange> KateRenderer::decorationsForLine(const Kate::TextLine &textLine, int line, bool selectionsOnly) const
+QList<QTextLayout::FormatRange> KateRenderer::decorationsForLine(const Kate::TextLine &textLine, int line, bool skipSelections) const
 {
     // limit number of attributes we can highlight in reasonable time
     const int limitOfRanges = 1024;
@@ -436,7 +430,7 @@ QList<QTextLayout::FormatRange> KateRenderer::decorationsForLine(const Kate::Tex
 
     // Don't compute the highlighting if there isn't going to be any highlighting
     const auto &al = textLine.attributesList();
-    if (!(selectionsOnly || !al.empty() || !rangesWithAttributes.empty())) {
+    if (al.empty() && rangesWithAttributes.empty() && !m_view->selection()) {
         return QList<QTextLayout::FormatRange>();
     }
 
@@ -489,7 +483,7 @@ QList<QTextLayout::FormatRange> KateRenderer::decorationsForLine(const Kate::Tex
     }
 
     // Add selection highlighting if we're creating the selection decorations
-    if ((m_view && selectionsOnly && showSelections() && m_view->selection()) || (m_view && m_view->blockSelection())) {
+    if (!skipSelections && ((m_view && showSelections() && m_view->selection()) || (m_view && m_view->blockSelection()))) {
         auto &currentRange = renderRanges.pushNewRange();
 
         // Set up the selection background attribute TODO: move this elsewhere, eg. into the config?
@@ -498,9 +492,7 @@ QList<QTextLayout::FormatRange> KateRenderer::decorationsForLine(const Kate::Tex
             backgroundAttribute = KTextEditor::Attribute::Ptr(new KTextEditor::Attribute());
         }
 
-        if (!hasCustomLineHeight()) {
-            backgroundAttribute->setBackground(config()->selectionColor());
-        }
+        backgroundAttribute->setBackground(config()->selectionColor());
         backgroundAttribute->setForeground(attribute(KSyntaxHighlighting::Theme::TextStyle::Normal)->selectedForeground().color());
 
         // Create a range for the current selection
@@ -517,27 +509,11 @@ QList<QTextLayout::FormatRange> KateRenderer::decorationsForLine(const Kate::Tex
     }
 
     // Calculate the range which we need to iterate in order to get the highlighting for just this line
-    KTextEditor::Cursor currentPosition;
-    KTextEditor::Cursor endPosition;
-    if (m_view && selectionsOnly) {
-        if (m_view->blockSelection()) {
-            KTextEditor::Range subRange = m_doc->rangeOnLine(m_view->selectionRange(), line);
-            currentPosition = subRange.start();
-            endPosition = subRange.end();
-        } else {
-            KTextEditor::Range rangeNeeded = m_view->selectionRange() & KTextEditor::Range(line, 0, line + 1, 0);
-
-            currentPosition = qMax(KTextEditor::Cursor(line, 0), rangeNeeded.start());
-            endPosition = qMin(KTextEditor::Cursor(line + 1, 0), rangeNeeded.end());
-        }
-    } else {
-        currentPosition = KTextEditor::Cursor(line, 0);
-        endPosition = KTextEditor::Cursor(line + 1, 0);
-    }
+    KTextEditor::Cursor currentPosition = KTextEditor::Cursor(line, 0);
+    const KTextEditor::Cursor endPosition = KTextEditor::Cursor(line + 1, 0);
 
     // Background formats have lower priority so they get overriden by selection
-    const bool shoudlClearBackground = m_view && hasCustomLineHeight() && m_view->selection();
-    const KTextEditor::Range selectionRange = shoudlClearBackground ? m_view->selectionRange() : KTextEditor::Range::invalid();
+    const KTextEditor::Range selectionRange = m_view->selectionRange();
 
     // Main iterative loop.  This walks through each set of highlighting ranges, and stops each
     // time the highlighting changes.  It then creates the corresponding QTextLayout::FormatRanges.
@@ -569,17 +545,11 @@ QList<QTextLayout::FormatRange> KateRenderer::decorationsForLine(const Kate::Tex
         KTextEditor::Attribute::Ptr a = renderRanges.generateAttribute();
         if (a) {
             fr.format = *a;
-
-            if (selectionsOnly) {
+            if (!skipSelections && selectionRange.contains(currentPosition)) {
                 assignSelectionBrushesFromAttribute(fr, *a);
             }
         }
 
-        // Clear background if this position overlaps selection
-        if (shoudlClearBackground && selectionRange.contains(currentPosition) && fr.format.hasProperty(QTextFormat::BackgroundBrush)) {
-            fr.format.clearBackground();
-        }
-
         newHighlight.append(fr);
 
         currentPosition = nextPosition;
@@ -605,26 +575,16 @@ void KateRenderer::assignSelectionBrushesFromAttribute(QTextLayout::FormatRange
     }
 }
 
-void KateRenderer::paintTextBackground(QPainter &paint,
-                                       KateLineLayout *layout,
-                                       const QList<QTextLayout::FormatRange> &selRanges,
-                                       const QBrush &brush,
-                                       int xStart) const
+void KateRenderer::paintTextBackground(QPainter &paint, KateLineLayout *layout, const QList<QTextLayout::FormatRange> &selRanges, int xStart) const
 {
     const bool rtl = layout->isRightToLeft();
 
     for (const auto &sel : selRanges) {
         const int s = sel.start;
         const int e = sel.start + sel.length;
-        QBrush br;
+        QBrush br = sel.format.background();
 
-        // Prefer using the brush supplied by user
-        if (brush != Qt::NoBrush) {
-            br = brush;
-        } else if (sel.format.background() != Qt::NoBrush) {
-            // Otherwise use the brush in format
-            br = sel.format.background();
-        } else {
+        if (br == Qt::NoBrush) {
             // skip if no brush to fill with
             continue;
         }
@@ -733,42 +693,18 @@ void KateRenderer::paintTextLine(QPainter &paint,
             }
         }
 
-        QList<QTextLayout::FormatRange> additionalFormats;
         if (range->length() > 0) {
             // We may have changed the pen, be absolutely sure it gets set back to
             // normal foreground color before drawing text for text that does not
             // set the pen color
             paint.setPen(attribute(KSyntaxHighlighting::Theme::TextStyle::Normal)->foreground().color());
+
+            // Draw text background
+            const auto decos = decorationsForLine(range->textLine(), range->line(), /*skipSelections=*/!drawSelection);
+            paintTextBackground(paint, range, decos, xStart);
+
             // Draw the text :)
-
-            if (range->layout().textOption().textDirection() == Qt::RightToLeft) {
-                // If the text is RTL, we draw text background ourselves
-                auto decos = decorationsForLine(range->textLine(), range->line(), false);
-                auto sr = view()->selectionRange();
-                auto c = config()->selectionColor();
-                int line = range->line();
-                // Remove "selection" format from decorations
-                // "selection" will get painted below
-                decos.erase(std::remove_if(decos.begin(),
-                                           decos.end(),
-                                           [sr, c, line](const QTextLayout::FormatRange &fr) {
-                                               return sr.overlapsLine(line) && sr.overlapsColumn(fr.start) && fr.format.background().color() == c;
-                                           }),
-                            decos.end());
-                paintTextBackground(paint, range, decos, Qt::NoBrush, xStart);
-            }
-
-            if (drawSelection) {
-                additionalFormats = decorationsForLine(range->textLine(), range->line(), true);
-                if (hasCustomLineHeight()) {
-                    paintTextBackground(paint, range, additionalFormats, config()->selectionColor(), xStart);
-                }
-                // DONT apply clipping, it breaks rendering when there are selections
-                range->layout().draw(&paint, QPoint(-xStart, 0), additionalFormats);
-
-            } else {
-                range->layout().draw(&paint, QPoint(-xStart, 0), QList<QTextLayout::FormatRange>{}, textClipRect);
-            }
+            range->layout().draw(&paint, QPoint(-xStart, 0), QList<QTextLayout::FormatRange>{}, textClipRect);
         }
 
         // Check if we are at a bracket and color the indentation
@@ -1248,7 +1184,7 @@ qreal KateRenderer::spaceWidth() const
     return m_fontMetrics.horizontalAdvance(spaceChar);
 }
 
-void KateRenderer::layoutLine(KateLineLayout *lineLayout, int maxwidth, bool cacheLayout) const
+void KateRenderer::layoutLine(KateLineLayout *lineLayout, int maxwidth, bool cacheLayout, bool skipSelections) const
 {
     // if maxwidth == -1 we have no wrap
 
@@ -1300,30 +1236,10 @@ void KateRenderer::layoutLine(KateLineLayout *lineLayout, int maxwidth, bool cac
     l.setTextOption(opt);
 
     // Syntax highlighting, inbuilt and arbitrary
-    QList<QTextLayout::FormatRange> decorations = decorationsForLine(textLine, lineLayout->line());
-
-    // Qt works badly if you have RTL text and formats set on that text.
-    // It will shape the text according to the given format ranges which
-    // produces incorrect results as a letter in RTL can have a different
-    // shape depending upon where in the word it resides. The resulting output
-    // looks like: وقار vs وق ار, i.e, the ligature قا is broken into ق ا which
-    // is really bad for readability
-    if (opt.textDirection() == Qt::RightToLeft) {
-        // We can fix this to a large extent here by using QGlyphRun etc, but for now
-        // we only fix this for formats which have a background color and a foreground
-        // color that is same as "dsNormal". Reasoning is that, it is unlikely that RTL
-        // text will have a lot of cases where you have partially colored ligatures. BG
-        // formats are different, you can easily have a format that covers a ligature partially
-        // as a result of "Search" or "multiple cursor selection"
-        QColor c = view()->theme().textColor(KSyntaxHighlighting::Theme::Normal);
-        decorations.erase(std::remove_if(decorations.begin(),
-                                         decorations.end(),
-                                         [c](const QTextLayout::FormatRange &fr) {
-                                             return fr.format.hasProperty(QTextFormat::BackgroundBrush)
-                                                 && (fr.format.property(QTextFormat::ForegroundBrush).value<QBrush>().color() == c
-                                                     || fr.format.foreground() == Qt::NoBrush);
-                                         }),
-                          decorations.end());
+    QList<QTextLayout::FormatRange> decorations = decorationsForLine(textLine, lineLayout->line(), skipSelections);
+    // clear background, that is draw separately
+    for (auto &decoration : decorations) {
+        decoration.format.clearBackground();
     }
 
     int firstLineOffset = 0;
@@ -1516,7 +1432,7 @@ void KateRenderer::paintSelection(QPaintDevice *d, int startLine, int xStart, in
         // compute layout WITHOUT cache to not poison it + render it
         KateLineLayout lineLayout(*this);
         lineLayout.setLine(line, -1);
-        layoutLine(&lineLayout, viewWidth, false /* no layout cache */);
+        layoutLine(&lineLayout, viewWidth, false /* no layout cache */, /*skipSelections=*/true);
         KateRenderer::PaintTextLineFlags flags;
         flags.setFlag(KateRenderer::SkipDrawFirstInvisibleLineUnderlined);
         flags.setFlag(KateRenderer::SkipDrawLineSelection);
