@@ -361,6 +361,8 @@ KateDocumentConfig::KateDocumentConfig()
 
     // Shall we do auto reloading for stuff e.g. in Git?
     addConfigEntry(ConfigEntry(AutoReloadIfStateIsInVersionControl, "Auto Reload If State Is In Version Control", QString(), true));
+    addConfigEntry(
+        ConfigEntry(AutoReloadOnExternalChanges, "Auto Reload If Any External Changes Occurs", QStringLiteral("auto-reload-on-external-changes"), false));
     // .editorconfig
     addConfigEntry(ConfigEntry(UseEditorConfig, "Use Editor Config", QString(), true));
 
@@ -740,7 +742,6 @@ void KateRendererConfig::readConfig(const KConfigGroup &config)
 
     // read font, including font features
     auto font = config.readEntry(KEY_FONT, QFontDatabase::systemFont(QFontDatabase::FixedFont));
-#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
     const QStringList rawFeaturesList = config.readEntry(KEY_FONT_FEATURES, QStringList());
     for (const QString &feature : rawFeaturesList) {
         const auto parts = feature.split(QStringLiteral("="), Qt::SkipEmptyParts);
@@ -753,7 +754,6 @@ void KateRendererConfig::readConfig(const KConfigGroup &config)
             }
         }
     }
-#endif
     setFont(font);
 
     // setSchema will default to right theme
@@ -780,7 +780,6 @@ void KateRendererConfig::writeConfig(KConfigGroup &config)
     // write font, including font features
     const auto font = baseFont();
     config.writeEntry(KEY_FONT, font);
-#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
     const auto tags = font.featureTags();
     QStringList features;
     for (const auto &tag : tags) {
@@ -789,7 +788,6 @@ void KateRendererConfig::writeConfig(KConfigGroup &config)
         features.push_back(QStringLiteral("%1=%2").arg(name, QString::number(value)));
     }
     config.writeEntry(KEY_FONT_FEATURES, features);
-#endif
 
     config.writeEntry(KEY_COLOR_THEME, schema());
 
